#!/bin/sh

usage () {
    {
        echo "Usage: $0"
        echo "Usage: $0 base"
        echo "Usage: $0 users"
        echo "Usage: $0 services [--deploy] [SERVICE]"
    } >&2
}

BASE_CMD="ansible-playbook playbook.yml"
DEPLOY="false"

if [ -z "$(ansible-galaxy collection list community.general 2>/dev/null)" ]; then
    echo "Installing community.general modules"
    ansible-galaxy collection install community.general
fi

if [ -z "$1" ]; then
    echo "Deploying all!"
    $BASE_CMD
else
    case $1 in
        "services")
            if [ -n "$2" && "$2" = "--deploy" ]; then
                DEPLOY="true"
                shift
            fi

            if [ -z "$2" ]; then
                echo "Deploying all services!"
                $BASE_CMD --tags setup_services --extra-vars "deploy_services=$DEPLOY"
            else
                echo "Deploying service: $2"
                $BASE_CMD --tags setup_services --extra-vars "deploy_services=$DEPLOY" --extra-vars "single_service=$2"
            fi
        ;;
        "base")
            $BASE_CMD --tags base_only
        ;;
        "users")
            $BASE_CMD --tags setup-users
        ;;
        *)
            usage
            exit 1
        ;;
    esac
fi
